#!/usr/bin/env bash

for filename in /etc/proxmox_helper/*.config; do
    # Load Image variables
    . "$filename"
    # Test if variables are set
    if ! [[  $IMAGE_NAME && ${IMAGE_NAME-x} ]]; then
        echo "Please set a IMAGE_NAME in ${filename}"
        exit 1
    fi
    if ! [[  $PROXMOX_ID && ${PROXMOX_ID-x} ]]; then
        echo "Please set a PROXMOX_ID in ${filename}"
        exit 1
    fi
    if ! [[  $TEMPLATE_NAME && ${TEMPLATE_NAME-x} ]]; then
        echo "Please set a TEMPLATE_NAME in ${filename}"
        exit 1
    fi
    # Load newest image from hermes
    /usr/bin/wget https://hermes.cps.io/images/"${IMAGE_NAME}".raw.gz -O /tmp/"${IMAGE_NAME}".raw.gz &>/dev/null
    if [ $? -ne 0 ]; then
        echo "[ERROR] Cannot download image"
        exit 1
    fi
    # Unpack the image
    /bin/gunzip /tmp/"${IMAGE_NAME}".raw.gz -f &>/dev/null
    if [ $? -ne 0 ]; then
        echo "[ERROR] Cannot unzip ${IMAGE_NAME}"
        exit 1
    fi
    # Delete template before recreating it and don't care if it isn't there
    /usr/sbin/qm destroy "${PROXMOX_ID}" || true
    # Create virtual machine here
    /usr/sbin/qm create "${PROXMOX_ID}" --net0 \
        virtio,bridge=vmbr21 \
        --name ${TEMPLATE_NAME} \
        --scsihw virtio-scsi-pci --ostype l26 --sockets 1 --template 1 \
        --onboot 1 --bootdisk virtio0 &>/dev/null
    if [ $? -ne 0 ]; then
        echo "[ERROR] Template creation failed"
        exit 1
    fi

    IFS='/' read -ra VERSION <<< $(pveversion)

    case ${VERSION[1]} in
        *4.*)
            pvesm alloc local-lvm "${PROXMOX_ID}" vm-"${PROXMOX_ID}"-disk-1 8G --format raw &> /dev/null
            if [ $? -ne 0 ]; then
                echo "[ERROR] lvm storage creation failed"
                exit 1
            fi
            qemu-img convert /tmp/"${IMAGE_NAME}".raw /dev/pve/vm-"${PROXMOX_ID}"-disk-1 &> /dev/null
            if [ $? -ne 0 ]; then
                echo "[ERROR] qemu img convert failed"
                exit 1
            fi
            ;;
        *5.*)
            # This imports the disk and saves it to the storage of vm 100 as unmanaged
            /usr/sbin/qm importdisk "${PROXMOX_ID}" /tmp/"${IMAGE_NAME}".raw local-lvm &>/dev/null
            if [ $? -ne 0 ]; then
                echo "[ERROR] importdisk failed"
                exit 1
            fi
            ;;
    esac

    # This set's it as managed device
    /usr/sbin/qm set "${PROXMOX_ID}" --virtio0 local-lvm:vm-"${PROXMOX_ID}"-disk-1 &>/dev/null
    if [ $? -ne 0 ]; then
        echo "[ERROR] Setting the bootdevice failed"
        exit 1
    fi

    unset IMAGE_NAME
    unset PROXMOX_ID
    unset TEMPLATE_NAME
done

exit 0
